%global __cmake_in_source_build 1

Summary:        A compression/decompression library
Name:           snappy
Version:        1.1.10
Release:        2%{?dist}
License:        BSD
URL:            https://github.com/google/snappy
Source0:        %{url}/archive/refs/tags/%{version}.tar.gz
Patch3000:      snappy-thirdparty.patch
Patch3001:      snappy-do-not-disable-rtti.patch

BuildRequires:  make cmake gcc-c++
BuildRequires:  google-benchmark-devel gtest-devel

%description
Snappy is a compression/decompression library. It does not aim for maximum 
compression, or compatibility with any other compression library; instead, 
it aims for very high speeds and reasonable compression. For instance, 
compared to the fastest mode of zlib, Snappy is an order of magnitude faster 
for most inputs, but the resulting compressed files are anywhere from 20% to 
100% bigger.

%package        devel
Summary:        Header files and libraries for snappy development
Requires:       %{name} = %{version}-%{release}
Requires:       cmake-filesystem pkgconfig

%description    devel
This package provides header files and libraries for snappy development.

%prep
%autosetup -p1

%build
# gtest 1.13.0 requires C++14 or later
%cmake -DCMAKE_CXX_STANDARD=14 -DSNAPPY_BUILD_TESTS=OFF .
%make_build

cat << EOF >snappy.pc
prefix=%{_prefix}
exec_prefix=%{_exec_prefix}
includedir=%{_includedir}
libdir=%{_libdir}

Name: %{name}
Description: A fast compression/decompression library
Version: %{version}
Cflags: -I\${includedir}
Libs: -L\${libdir} -lsnappy
EOF

%install
%make_install
install -D -m 0644 snappy.pc %{buildroot}%{_libdir}/pkgconfig/snappy.pc

%check
ctest -V %{?_smp_mflags}

%files
%license COPYING
%doc AUTHORS NEWS README.md
%{_libdir}/libsnappy.so.*

%files devel
%doc format_description.txt framing_format.txt
%{_includedir}/snappy*.h
%{_libdir}/libsnappy.so
%{_libdir}/pkgconfig/snappy.pc
%{_libdir}/cmake/Snappy/

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.10-2
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Aug 18 2023 Miaojun Dong <zoedong@tencent.com> - 1.1.10-1
- Bump version to 1.1.10

* Mon Aug 14 2023 Shuo Wang <abushwang@tencent.com> - 1.1.9-4
- close SNAPPY_BUILD_TESTS due to requires to c++14

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.9-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.1.9-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Jul 27 2022 Xiaojie Chen <jackxjchen@tencent.com> - 1.1.9-1
- Initial build
